@@ -1,6 +1,15 @@
 ######################## RNIGHTLIGHTSOPTIONS ###################################
 
 RNIGHTLIGHTSOPTIONS <- settings::options_manager(
+  #Specify the regex to uniquely identify the tile file
+  #to extract from the download tile tar.gz
+  #more info at: https://ngdc.noaa.gov/eog/viirs/download_dnb_composites.html
+  configName_VIIRS.D = "vcmcfg",
+  
+  configName_VIIRS.M = "vcmcfg",
+  
+  configName_VIIRS.Y = "vcm-orm-ntl",
+  
   #cropMaskMethod" Method used to crop and mask tiles to country polygons. 
   #options: "gdal" or "rast" gdal is usually faster but requires gdal to be installed on the system
   cropMaskMethod = "rast",
@@ -31,7 +40,7 @@ RNIGHTLIGHTSOPTIONS <- settings::options_manager(
   extractMethod = "rast",
 
   #the gadm polygons to use
-  gadmVersion = "2.8",
+  gadmVersion = "3.6",
   
   #gdalCacheMax Speeds up gdal_rasterize calculation of stats in function ZonalPipe with more cache (advice: max 1/3 of your total RAM) see: http://www.guru-gis.net/efficient-zonal-statistics-using-r-and-gdal/
   gdalCacheMax = 1024,
@@ -61,6 +70,9 @@ RNIGHTLIGHTSOPTIONS <- settings::options_manager(
   tmpDir = raster::tmpDir(),
 
   .allowed = list(
+    configName_VIIRS.D = settings::inlist("vcmcfg", "vcmsl"),
+    configName_VIIRS.M = settings::inlist("vcmcfg", "vcmsl"),
+    configName_VIIRS.Y = settings::inlist("vcm-orm", "vcm-orm-ntl", "vcm-ntl"),
     cropMaskMethod = settings::inlist("gdal","rast"),
     extractMethod = settings::inlist("gdal", "rast"),
     downloadMethod = settings::inlist("aria", "auto", "curl", "libcurl", "wget"),
@@ -73,11 +85,48 @@ RNIGHTLIGHTSOPTIONS <- settings::options_manager(
 
 #' Set or get options for the Rnightlights package
 #' 
-#' @param ... Option names to retrieve option values or \code{[key]=[value]} pairs to set options.
+#' @param ... Option names to retrieve option values or \code{[key]=[value]}
+#'     pairs to set options.
 #'
 #' @section Supported options:
 #' The following options are supported
-#' \itemize{
+#' \describe{
+#'  \item{\code{configName.VIIRS.D}}{(\code{character}) The regex to uniquely
+#'      identify the tile file to use out of the downloaded tile .tgz. The
+#'      version 1 monthly series is run globally using two different 
+#'      configurations.
+#'      
+#'      The first excludes any data impacted by stray light. The second
+#'      includes these data if the radiance vales have undergone the stray-
+#'      light correction procedure (Reference). These two configurations
+#'      are denoted in the filenames as "vcm" and "vcmsl" respectively.
+#'      The "vcmsl" version, that includes the stray-light corrected data,
+#'      will have more data coverage toward the poles, but will be of reduced
+#'      quality.
+#'      
+#'      It is up to the users to determine which set is best for their
+#'      applications. The annual versions are only made with the "vcm"
+#'      version, excluding any data impacted by stray light.}
+#'      
+#'  \item{\code{configName.VIIRS.M}}{(\code{character}) The regex to uniquely
+#'      identify the tile file to use out of the downloaded monthly .tgz
+#'      tile. Has the same options as configName.VIIRS.D}
+#'  
+#'  \item{\code{configName.VIIRS.Y}}{(\code{character}) The regex to uniquely
+#'      identify the tile file to use out of the downloaded tile .tgz. The
+#'      annual products can have other values for the config shortname (Field 5).
+#'      They are:
+#'      \itemize{
+#'        \item vcm-orm \emph{(VIIRS Cloud Mask - Outlier Removed)}: This product
+#'          contains cloud-free average radiance values that have undergone
+#'          an outlier removal process to filter out fires and other ephemeral
+#'          lights.
+#'        \item vcm-orm-ntl \emph{(VIIRS Cloud Mask - Outlier Removed - Nighttime Lights)}:
+#'          This product contains the "vcm-orm" average, with background
+#'          (non-lights) set to zero.
+#'        \item vcm-ntl \emph{(VIIRS Cloud Mask - Nighttime Lights)}: This product
+#'          contains the "vcm" average, with background
+#'          (non-lights) set to zero.}}
 #'  \item{\code{cropMaskMethod}}{(\code{character}) The method to use to 
 #'      clip the nightlight raster tiles to the country boundaries }
 #'  \item{\code{deleteTiles}}{(\code{character}) whether to delete tiles 
