@@ -85,6 +85,12 @@ gadmAliasToLayer <- function(layerAlias, gadmVersion=pkgOptions("gadmVersion"))
 #'
 orderCustPolyLayers <- function(ctryCode, custPolyPath=NULL)
 {
+  if(is.null(custPolyPath))
+    stop(Sys.time(), ": Missing required parameter custPolyPath")
+  
+  if(!is.null(ctryCode) && !validCtryCodes(ctryCode))
+    stop(Sys.time(), ": Invalid ISO3 ctryCode: ", ctryCode)
+  
   polyFnamePath <- getPolyFnamePath(ctryCode = ctryCode, custPolyPath = custPolyPath)
   
   lyrNames <- rgdal::ogrListLayers(polyFnamePath)
@@ -137,7 +143,7 @@ addCtryPolyIdx <- function(ctryCode, gadmVersion=pkgOptions("gadmVersion"), cust
       ctryPoly <- rgdal::readOGR(dsn = getPolyFnamePath(ctryCode = ctryCode, gadmVersion = gadmVersion, custPolyPath = custPolyPath), layer = admLevel)
       
       #Create an integer col in the shapefile with unique GIDs
-        message("Creating integer zone attribute col for polygon")
+        message(Sys.time(), ": Creating integer zone attribute col for polygon")
         
         lowestIDCol <- "GID_IDX"
         
@@ -146,7 +152,7 @@ addCtryPolyIdx <- function(ctryCode, gadmVersion=pkgOptions("gadmVersion"), cust
         #project to wgs84
         ctryPoly <- sp::spTransform(ctryPoly, sp::CRS(wgs84))
           
-        message("Writing layer with new idx col")
+        message(Sys.time(), ": Writing layer with new idx col")
         rgdal::writeOGR(obj = ctryPoly,
                         dsn = getPolyFnamePath(ctryCode = ctryCode,
                                                gadmVersion = gadmVersion,
@@ -168,13 +174,13 @@ addCtryPolyIdx <- function(ctryCode, gadmVersion=pkgOptions("gadmVersion"), cust
       #Create an integer col in the shapefile corresponding to the unique GIDs
       if(is.null(ctryPoly@data[[lowestIDCol]]))
       {
-        message("Creating integer zone attribute col for polygon")
+        message(Sys.time(), ": Creating integer zone attribute col for polygon")
         
         lowestIDColOrig <- gsub("_IDX", "", lowestIDCol)
         
         ctryPoly@data[,lowestIDCol] <- 1:length(sort(ctryPoly@data[,lowestIDColOrig]))  # Make new attribute
         
-        message("Writing layer with new idx col")
+        message(Sys.time(), ": Writing layer with new idx col")
         rgdal::writeOGR(obj = ctryPoly,
                         dsn = getPolyFnamePath(ctryCode = ctryCode,
                                                gadmVersion = gadmVersion,
@@ -208,15 +214,15 @@ addCtryPolyIdx <- function(ctryCode, gadmVersion=pkgOptions("gadmVersion"), cust
 #' Rnightlights:::dnldCtryPoly("KEN")
 #' }
 #'
-dnldCtryPoly <- function(ctryCode, gadmVersion=pkgOptions("gadmVersion"), custPolyPath=NULL, downloadMethod=pkgOptions("downloadMethod"))
+dnldCtryPoly <- function(ctryCode=NULL, gadmVersion=pkgOptions("gadmVersion"), custPolyPath=NULL, downloadMethod=pkgOptions("downloadMethod"))
 {
-  if(missing(ctryCode))
-    stop("Missing required parameter ctryCode")
+  if(is.null(ctryCode) && is.null(custPolyPath))
+    stop(Sys.time(), ": Missing required parameter. One of ctryCode/custPolyPath required")
   
-  if(!validCtryCodes(ctryCode))
-    stop("Invalid ctryCode: ", ctryCode)
-  
-  message("Downloading ctry poly: ", ctryCode)
+  if(!is.null(ctryCode) && !validCtryCodes(ctryCode))
+    stop(Sys.time(), ": Invalid ISO3 ctryCode: ", ctryCode)
+
+  message(Sys.time(), ": Downloading ctry poly: ", ctryCode)
   
   fullPolyUrl <- getCtryPolyUrl(ctryCode = ctryCode, gadmVersion = gadmVersion, custPolyPath = custPolyPath)
   
@@ -228,10 +234,11 @@ dnldCtryPoly <- function(ctryCode, gadmVersion=pkgOptions("gadmVersion"), custPo
     #if the dir and zip dont exist download and unzip
     if (!existsPolyFnameZip(ctryCode = ctryCode, gadmVersion = gadmVersion, custPolyPath = custPolyPath))
     {
-      #download
-      
-      #downloadMethod <- pkgOptions("downloadMethod")
+      #do not use aria. Seems GADM has issues with it. Use auto
+      downloadMethod <- "auto"
 
+      message(Sys.time(), ": Downloading ", fullPolyUrl)
+      
       if (downloadMethod %in% c("auto", "curl", "libcurl", "wget"))
         rsltDnld <- utils::download.file(url = fullPolyUrl,
                                          destfile = getPolyFnameZip(ctryCode = ctryCode,
@@ -241,7 +248,7 @@ dnldCtryPoly <- function(ctryCode, gadmVersion=pkgOptions("gadmVersion"), custPo
                                          mode = "wb",
                                          extra = "-c")
       else if (downloadMethod == "aria")
-        rsltDnld <- system(paste0("aria2c -c -x2 ", fullPolyUrl,
+        rsltDnld <- system(paste0("aria2c -c -x2 --show-console-readout=false --summary-interval=10 ", fullPolyUrl,
                                   " -d ", getNlDir("dirPolygon"),
                                   " -o ", basename(getPolyFnameZip(ctryCode = ctryCode,
                                                                    gadmVersion = gadmVersion,
@@ -267,7 +274,7 @@ dnldCtryPoly <- function(ctryCode, gadmVersion=pkgOptions("gadmVersion"), custPo
           addCtryPolyIdx(ctryCode = ctryCode, gadmVersion = gadmVersion, custPolyPath = custPolyPath)
       }else
       {
-        stop("Something went wrong. Polygon download failed!")
+        stop(Sys.time(), ": Something went wrong. Polygon download failed!")
       }
     }else
     {
@@ -300,36 +307,36 @@ dnldCtryPoly <- function(ctryCode, gadmVersion=pkgOptions("gadmVersion"), custPo
     wgs84 <- "+proj=longlat +datum=WGS84 +ellps=WGS84 +towgs84=0,0,0"
     
     #saving RDS
-    message("Saving shapefile as RDS for faster access")
-    message("Getting admLevels in ", ctryCode)
+    message(Sys.time(), ": Saving shapefile as RDS for faster access")
+    message(Sys.time(), ": Getting admLevels in ", ctryCode)
     if(is.null(custPolyPath))
       allCtryLevels <- sort(unlist(grep("adm", rgdal::ogrListLayers(getPolyFnamePath(ctryCode = ctryCode, gadmVersion = gadmVersion, custPolyPath = custPolyPath)), value = T)))
     else
       allCtryLevels <- rgdal::ogrListLayers(getPolyFnamePath(ctryCode = ctryCode, gadmVersion = gadmVersion, custPolyPath = custPolyPath))
     
-    message("Reading in all admLevels")
+    message(Sys.time(), ": Reading in all admLevels")
     listCtryPolys <- unlist(lapply(allCtryLevels, function(lvl){ ctryPoly <- rgdal::readOGR(dsn = getPolyFnamePath(ctryCode = ctryCode, gadmVersion = gadmVersion, custPolyPath = custPolyPath), layer = lvl)}))
     
-    message("Saving admLevel polygons as RDS")
+    message(Sys.time(), ": Saving admLevel polygons as RDS")
     saveRDS(object = listCtryPolys, file = getPolyFnameRDS(ctryCode = ctryCode, gadmVersion = gadmVersion, custPolyPath = custPolyPath))
   }
   else
   {
-    message("Polygon dir for ", ctryCode, " already exists")
+    message(Sys.time(), ": Polygon dir for ", paste(ctryCode, ifelse(is.null(custPolyPath), gadmVersion, basename(custPolyPath)), sep = ":"), " already exists")
     
     if(!file.exists(getPolyFnameRDS(ctryCode = ctryCode, gadmVersion = gadmVersion, custPolyPath = custPolyPath)))
     {
-      message("Saving shapefile as RDS for faster access")
-      message("Getting admLevels in ", ctryCode)
+      message(Sys.time(), ": Saving shapefile as RDS for faster access")
+      message(Sys.time(), ": Getting admLevels in ", ctryCode)
       if(is.null(custPolyPath))
         allCtryLevels <- sort(unlist(grep("adm", rgdal::ogrListLayers(dsn = getPolyFnamePath(ctryCode = ctryCode, gadmVersion = gadmVersion, custPolyPath = custPolyPath)), value = T)))
       else
         allCtryLevels <- rgdal::ogrListLayers(getPolyFnamePath(ctryCode = ctryCode, gadmVersion = gadmVersion, custPolyPath = custPolyPath))
       
-      message("Reading in all admLevels")
+      message(Sys.time(), ": Reading in all admLevels")
       listCtryPolys <- unlist(lapply(allCtryLevels, function(lvl){ ctryPoly <- rgdal::readOGR(dsn = getPolyFnamePath(ctryCode = ctryCode, gadmVersion = gadmVersion, custPolyPath = custPolyPath), layer = lvl); ctryPoly <- cleangeo::clgeo_Clean(ctryPoly)}))
       
-      message("Saving admLevel polygons as RDS")
+      message(Sys.time(), ": Saving admLevel polygons as RDS")
       saveRDS(listCtryPolys, getPolyFnameRDS(ctryCode = ctryCode, gadmVersion = gadmVersion, custPolyPath = custPolyPath))
     }
   }
@@ -337,7 +344,7 @@ dnldCtryPoly <- function(ctryCode, gadmVersion=pkgOptions("gadmVersion"), custPo
   #save ctry structure as CSV in data dir
   if(!file.exists(getCtryStructFnamePath(ctryCode = ctryCode, gadmVersion = gadmVersion, custPolyPath = custPolyPath)))
   {
-    message("Saving country admLevel structure to CSV")
+    message(Sys.time(), ": Saving country admLevel structure to CSV")
   
     createCtryStruct(ctryCode = ctryCode, gadmVersion = gadmVersion, custPolyPath = custPolyPath)
   }
@@ -362,12 +369,18 @@ dnldCtryPoly <- function(ctryCode, gadmVersion=pkgOptions("gadmVersion"), custPo
 #' @examples
 #' Rnightlights:::getCtryStructFname("KEN")
 #'
-getCtryStructFname <- function(ctryCode, gadmVersion=pkgOptions("gadmVersion"), custPolyPath=NULL)
+getCtryStructFname <- function(ctryCode=NULL, gadmVersion=pkgOptions("gadmVersion"), custPolyPath=NULL)
 {
+  if(is.null(ctryCode) && is.null(custPolyPath))
+    stop(Sys.time(), ": Missing required parameter ctryCode")
+  
+  if(!is.null(ctryCode) && !allValidCtryCodes(ctryCodes = ctryCode))
+    stop(Sys.time(), ": Invalid ctryCode(s) detected ")
+  
   fName <- if(is.null(custPolyPath))
               paste0("NL_STRUCT_", ctryCode, "_GADM-", gadmVersion, ".csv")
             else
-              paste0("NL_STRUCT_", ctryCode, "_CUST-", basename(custPolyPath), ".csv")
+              paste0("NL_STRUCT_", ifelse(is.null(ctryCode), "", paste0(ctryCode, "_")), "CUST-", basename(custPolyPath), ".csv")
   
   return(fName)
 }
@@ -389,8 +402,14 @@ getCtryStructFname <- function(ctryCode, gadmVersion=pkgOptions("gadmVersion"),
 #' @examples
 #' Rnightlights:::getCtryStructFnamePath("KEN")
 #'
-getCtryStructFnamePath <- function(ctryCode, gadmVersion=pkgOptions("gadmVersion"), custPolyPath=NULL)
+getCtryStructFnamePath <- function(ctryCode=NULL, gadmVersion=pkgOptions("gadmVersion"), custPolyPath=NULL)
 {
+  if(is.null(ctryCode) && is.null(custPolyPath))
+    stop(Sys.time(), ": Missing required parameter ctryCode")
+  
+  if(!is.null(ctryCode) && !allValidCtryCodes(ctryCodes = ctryCode))
+    stop(Sys.time(), ": Invalid ctryCode(s) detected ")
+  
   return(file.path(getNlDir("dirNlData"), getCtryStructFname(ctryCode = ctryCode, gadmVersion = gadmVersion, custPolyPath = custPolyPath)))
 }
 
@@ -413,13 +432,19 @@ getCtryStructFnamePath <- function(ctryCode, gadmVersion=pkgOptions("gadmVersion
 #'   Rnightlights:::createCtryStruct("KEN")
 #' }
 #'
-createCtryStruct <- function(ctryCode, gadmVersion=pkgOptions("gadmVersion"), custPolyPath=NULL)
+createCtryStruct <- function(ctryCode=NULL, gadmVersion=pkgOptions("gadmVersion"), custPolyPath=NULL)
 {
+  if(is.null(ctryCode) && is.null(custPolyPath))
+    stop(Sys.time(), ": Missing required parameter ctryCode")
+  
+  if(!is.null(ctryCode) && !allValidCtryCodes(ctryCodes = ctryCode))
+    stop(Sys.time(), ": Invalid ctryCode(s) detected ")
+  
   ctryStructFnamePath <- getCtryStructFnamePath(ctryCode = ctryCode, gadmVersion = gadmVersion, custPolyPath = custPolyPath)
   
   if(!exists(ctryStructFnamePath))
   {
-    ctryNlDataDF <- createCtryNlDataDF(ctryCode = ctryCode, admLevel = getCtryShpLowestLyrNames(ctryCodes = ctryCode, gadmVersion = gadmVersion, custPolyPath = custPolyPath), custPolyPath = custPolyPath)
+    ctryNlDataDF <- createCtryNlDataDF(ctryCode = ctryCode, admLevel = getCtryShpLowestLyrNames(ctryCodes = ctryCode, gadmVersion = gadmVersion, custPolyPath = custPolyPath), gadmVersion = gadmVersion, custPolyPath = custPolyPath)
     
     utils::write.table(x = ctryNlDataDF, file = ctryStructFnamePath, row.names = F, sep = ",")
   }
@@ -444,8 +469,14 @@ createCtryStruct <- function(ctryCode, gadmVersion=pkgOptions("gadmVersion"), cu
 #' Rnightlights:::createCtryStruct("KEN")
 #' }
 #'
-readCtryStruct <- function(ctryCode, gadmVersion=pkgOptions("gadmVersion"), custPolyPath=NULL)
+readCtryStruct <- function(ctryCode=NULL, gadmVersion=pkgOptions("gadmVersion"), custPolyPath=NULL)
 {
+  if(is.null(ctryCode) && is.null(custPolyPath))
+    stop(Sys.time(), ": Missing required parameter ctryCode")
+  
+  if(!is.null(ctryCode) && !allValidCtryCodes(ctryCodes = ctryCode))
+    stop(Sys.time(), ": Invalid ctryCode(s) detected ")
+  
   nlCtryData <- NULL
   
   ctryStructFnamePath <- getCtryStructFnamePath(ctryCode = ctryCode, gadmVersion = gadmVersion, custPolyPath = custPolyPath)
@@ -487,26 +518,23 @@ readCtryStruct <- function(ctryCode, gadmVersion=pkgOptions("gadmVersion"), cust
 #' Rnightlights:::getCtryPolyUrl(ctryCode)
 #'  #returns url for the zipped country ESRI shapefile
 #'
-getCtryPolyUrl <- function(ctryCode, gadmVersion=pkgOptions("gadmVersion"), custPolyPath=NULL)
+getCtryPolyUrl <- function(ctryCode=NULL, gadmVersion=pkgOptions("gadmVersion"), custPolyPath=NULL)
 {
-  if(missing(ctryCode))
-    stop("Missing required parameter ctryCode")
+  if(is.null(ctryCode) && is.null(custPolyPath))
+    stop(Sys.time(), ": Missing required parameter ctryCode")
   
-  if(!validCtryCodes(ctryCode))
-    stop("Invalid ctryCode: ", ctryCode)
-  
-  if(missing(custPolyPath))
-    custPolyPath <- NULL
+  if(!is.null(ctryCode) && !allValidCtryCodes(ctryCodes = ctryCode))
+    stop(Sys.time(), ": Invalid ctryCode(s) detected ")
   
   if(is.null(custPolyPath))
   {
-    #Sample url: http://biogeo.ucdavis.edu/data/gadm2.8/shp/AFG_adm_shp.zip
+    #Sample url: https://biogeo.ucdavis.edu/data/gadm2.8/shp/AFG_adm_shp.zip
     ctryPolyUrl <- if(gadmVersion == "2.8")
-      paste0("http://biogeo.ucdavis.edu/data/gadm2.8/shp/", ctryCode, "_adm_shp.zip")
+      paste0("https://biogeo.ucdavis.edu/data/gadm2.8/shp/", ctryCode, "_adm_shp.zip")
     else if(gadmVersion == "3.6")
-      paste0("http://biogeo.ucdavis.edu/data/gadm3.6/shp/gadm36_", ctryCode, "_shp.zip")
+      paste0("https://biogeo.ucdavis.edu/data/gadm3.6/shp/gadm36_", ctryCode, "_shp.zip")
     else
-      stop("Invalid gadmVersion")
+      stop(Sys.time(), ": Invalid gadmVersion")
   }else
   {
     #return custPolyPath as a url taking into account whether it is a relative path
@@ -534,8 +562,14 @@ getCtryPolyUrl <- function(ctryCode, gadmVersion=pkgOptions("gadmVersion"), cust
 #' Rnightlights:::existsPolyFnamePath("KEN")
 #'  #returns TRUE/FALSE
 #'
-existsPolyFnamePath <- function(ctryCode, gadmVersion=pkgOptions("gadmVersion"), custPolyPath=NULL)
+existsPolyFnamePath <- function(ctryCode=NULL, gadmVersion=pkgOptions("gadmVersion"), custPolyPath=NULL)
 {
+  if(is.null(ctryCode) && is.null(custPolyPath))
+    stop(Sys.time(), ": Missing required parameter ctryCode")
+  
+  if(!is.null(ctryCode) && !allValidCtryCodes(ctryCodes = ctryCode))
+    stop(Sys.time(), ": Invalid ctryCode(s) detected ")
+  
   #for polygons look for shapefile dir
   return(dir.exists(getPolyFnamePath(ctryCode = ctryCode, gadmVersion = gadmVersion, custPolyPath = custPolyPath)))
 }
@@ -558,13 +592,16 @@ existsPolyFnamePath <- function(ctryCode, gadmVersion=pkgOptions("gadmVersion"),
 #' Rnightlights:::existsPolyFnameZip("KEN")
 #'  #returns TRUE/FALSE
 #'
-existsPolyFnameZip <- function(ctryCode, gadmVersion=pkgOptions("gadmVersion"), custPolyPath=NULL)
+existsPolyFnameZip <- function(ctryCode=NULL, gadmVersion=pkgOptions("gadmVersion"), custPolyPath=NULL)
 {
-  if(missing(ctryCode))
-    stop("Missing required parameter ctryCode")
+  # if(missing(ctryCode))
+  #   stop(Sys.time(), ": Missing required parameter ctryCode")
   
-  if(!validCtryCodes(ctryCode))
-    stop("Invalid ctryCode: ", ctryCode)
+  if(is.null(ctryCode) && is.null(custPolyPath))
+    stop(Sys.time(), ": Missing required parameter ctryCode")
+  
+  if(!is.null(ctryCode) && !allValidCtryCodes(ctryCodes = ctryCode))
+    stop(Sys.time(), ": Invalid ctryCode(s) detected ")
   
   return(file.exists(getPolyFnameZip(ctryCode = ctryCode, gadmVersion = gadmVersion, custPolyPath = custPolyPath)))
 }
@@ -603,13 +640,16 @@ existsPolyFnameZip <- function(ctryCode, gadmVersion=pkgOptions("gadmVersion"),
 #' 
 #' #export only due to exploreData() shiny app
 #' @export
-getCtryShpLyrNames <- function(ctryCodes, lyrNums, dnldPoly, gadmVersion=pkgOptions("gadmVersion"), custPolyPath=NULL)
+getCtryShpLyrNames <- function(ctryCodes=NULL, lyrNums, dnldPoly, gadmVersion=pkgOptions("gadmVersion"), custPolyPath=NULL)
 {
-  if(missing(ctryCodes))
-    stop("Missing required parameter ctryCode")
+  #if(missing(ctryCodes))
+  #  stop(Sys.time(), ": Missing required parameter ctryCode")
   
-  if(!allValidCtryCodes(ctryCodes))
-    stop("Invalid ctryCode detected")
+  if(is.null(ctryCodes) && is.null(custPolyPath))
+    stop(Sys.time(), ": Missing required parameter ctryCode")
+  
+  if(!is.null(ctryCodes) && !allValidCtryCodes(ctryCodes = ctryCodes))
+    stop(Sys.time(), ": Invalid ctryCode(s) detected ")
   
   if(missing(dnldPoly))
     dnldPoly <- TRUE
@@ -619,7 +659,7 @@ getCtryShpLyrNames <- function(ctryCodes, lyrNums, dnldPoly, gadmVersion=pkgOpti
   
   if(!existsCtryPoly(ctryCode = ctryCodes, gadmVersion = gadmVersion, custPolyPath = custPolyPath))
     if(!dnldPoly)
-      message("ctryPoly doesn't exist. Set dnldPoly=TRUE to download it")
+      message(Sys.time(), ": ctryPoly doesn't exist. Set dnldPoly=TRUE to download it")
   else
     dnldCtryPoly(ctryCode = ctryCodes, gadmVersion = gadmVersion, custPolyPath = custPolyPath)
   
@@ -665,19 +705,19 @@ getCtryShpLyrNames <- function(ctryCodes, lyrNums, dnldPoly, gadmVersion=pkgOpti
 #' 
 #' @return character string The name of the lowest admin level
 #'
-getCtryShpLowestLyrNames <- function(ctryCodes, gadmVersion=pkgOptions("gadmVersion"), custPolyPath=NULL)
+getCtryShpLowestLyrNames <- function(ctryCodes=NULL, gadmVersion=pkgOptions("gadmVersion"), custPolyPath=NULL)
 {
-  if(missing(ctryCodes))
-    stop("Missing required parameter ctryCode")
+  if(is.null(ctryCodes) && is.null(custPolyPath))
+    stop(Sys.time(), ": Missing required parameter ctryCode")
   
-  if(!allValidCtryCodes(ctryCodes = ctryCodes))
-    stop("Invalid ctryCode(s) detected ")
+  if(!is.null(ctryCodes) && !allValidCtryCodes(ctryCodes = ctryCodes))
+    stop(Sys.time(), ": Invalid ctryCode(s) detected")
   
   if(!dir.exists(path.expand(getPolyFnamePath(ctryCode = ctryCodes, gadmVersion = gadmVersion, custPolyPath = custPolyPath))))
     dnldCtryPoly(ctryCode = ctryCodes, gadmVersion = gadmVersion, custPolyPath = custPolyPath)
   
   if(!dir.exists(path.expand(getPolyFnamePath(ctryCode = ctryCodes, gadmVersion = gadmVersion, custPolyPath = custPolyPath))))
-    stop("Unable to find/download ctry polygon")
+    stop(Sys.time(), ": Unable to find/download ctry polygon")
   
   lowestAdmLyrNames <- sapply(ctryCodes,
                               function(ctryCode)
@@ -721,22 +761,22 @@ getCtryShpLowestLyrNames <- function(ctryCodes, gadmVersion=pkgOptions("gadmVers
 #' #if KEN shapefile exists otherwise errors
 #' }
 #'
-getCtryPolyAdmLevelNames <- function(ctryCode, lowestAdmLevel, gadmVersion=pkgOptions("gadmVersion"), custPolyPath=NULL)
+getCtryPolyAdmLevelNames <- function(ctryCode=NULL, lowestAdmLevel, gadmVersion=pkgOptions("gadmVersion"), custPolyPath=NULL)
 {
-  if(missing(ctryCode))
-    stop("Missing required parameter ctryCode")
+  if(is.null(custPolyPath) && is.null(ctryCode))
+    stop(Sys.time(), ": Missing required parameter ctryCode")
   
-  if(!validCtryCodes(ctryCode))
-    stop("Invalid ISO3 ctryCode: ", ctryCode)
+  if(!is.null(ctryCode) && !allValidCtryCodes(ctryCodes = ctryCode))
+    stop(Sys.time(), ": Invalid ctryCode(s) detected ")
   
   if(missing(lowestAdmLevel))
-    lowestAdmLevel <- getCtryShpLowestLyrNames(ctryCodes = ctryCode, gadmVersion = gadmVersion, custPolyPath = custPolyPath)
+    lowestLayer <- getCtryShpLowestLyrNames(ctryCodes = ctryCode, gadmVersion = gadmVersion, custPolyPath = custPolyPath)
+  else
+    lowestLayer <- lowestAdmLevel
   
   if(missing(custPolyPath))
     custPolyPath <- NULL
   
-  lowestLayer <- lowestAdmLevel
-  
   allLayers <- rgdal::ogrListLayers(dsn = getPolyFnamePath(ctryCode = ctryCode, gadmVersion = gadmVersion, custPolyPath = custPolyPath))
   
   #gadm layers if out of order should be sorted by name. The X=integer in KEN_admX ensures correct order
@@ -754,7 +794,7 @@ getCtryPolyAdmLevelNames <- function(ctryCode, lowestAdmLevel, gadmVersion=pkgOp
   {
     for (lyrNum in 0:layerNum)
     {
-      lyrPoly <- readCtryPolyAdmLayer(ctryCode = ctryCode, admLevel = as.character(getCtryShpLyrNames(ctryCode, lyrNum, gadmVersion = gadmVersion, custPolyPath = custPolyPath)), custPolyPath = custPolyPath)
+      lyrPoly <- readCtryPolyAdmLayer(ctryCode = ctryCode, admLevel = as.character(getCtryShpLyrNames(ctryCode, lyrNum, gadmVersion = gadmVersion, custPolyPath = custPolyPath)), gadmVersion = gadmVersion, custPolyPath = custPolyPath)
       
       if(lyrNum > 0)
       {
@@ -821,13 +861,13 @@ getCtryPolyAdmLevelNames <- function(ctryCode, lowestAdmLevel, gadmVersion=pkgOp
 #' #if KEN shapefile exists otherwise errors
 #' }
 #'
-getCtryStructAdmLevelNames <- function(ctryCode, lowestAdmLevel, gadmVersion=pkgOptions("gadmVersion"), custPolyPath=NULL)
+getCtryStructAdmLevelNames <- function(ctryCode=NULL, lowestAdmLevel, gadmVersion=pkgOptions("gadmVersion"), custPolyPath=NULL)
 {
-  if(missing(ctryCode))
-    stop("Missing required parameter ctryCode")
+  if(is.null(custPolyPath) && missing(ctryCode))
+    stop(Sys.time(), ": Missing required parameter ctryCode")
   
-  if(!validCtryCodes(ctryCode))
-    stop("Invalid ISO3 ctryCode: ", ctryCode)
+  if(!is.null(ctryCode) && !validCtryCodes(ctryCode))
+    stop(Sys.time(), ": Invalid ISO3 ctryCode: ", ctryCode)
   
   if(missing(lowestAdmLevel))
     lowestAdmLevel <- getCtryShpLowestLyrNames(ctryCodes = ctryCode, gadmVersion = gadmVersion, custPolyPath = custPolyPath)
@@ -835,6 +875,7 @@ getCtryStructAdmLevelNames <- function(ctryCode, lowestAdmLevel, gadmVersion=pkg
   if(missing(custPolyPath))
     custPolyPath <- NULL
   
+  #why not directy assign?
   lowestLayer <- lowestAdmLevel
   
   allLayers <- rgdal::ogrListLayers(dsn = getPolyFnamePath(ctryCode = ctryCode, gadmVersion = gadmVersion, custPolyPath = custPolyPath))
@@ -850,27 +891,40 @@ getCtryStructAdmLevelNames <- function(ctryCode, lowestAdmLevel, gadmVersion=pkg
   
   admLevels <- NULL
   
-  #get the names of each layer starting from level 1
-  if (length(layerNum) > 0 && layerNum > 0)
+  if(length(layerNum) > 0)
   {
-    lvlNames <- names(readCtryStruct(ctryCode = ctryCode, gadmVersion = gadmVersion, custPolyPath = custPolyPath))
-    lvlNames <- lvlNames[-c(length(lvlNames))]
-    
-    for (lyrNum in 1:(layerNum)) #skip country layer
+    #get the names of each layer starting from level 1
+    if (layerNum > 0)
     {
-      admLevels <- c(admLevels, lvlNames[lyrNum])
+      lvlNames <- names(readCtryStruct(ctryCode = ctryCode, gadmVersion = gadmVersion, custPolyPath = custPolyPath))
+      lvlNames <- lvlNames[-c(length(lvlNames))]
+      
+      for (lyrNum in 1:(layerNum)) #skip country layer
+      {
+        admLevels <- c(admLevels, lvlNames[lyrNum])
+      }
+    }else if (layerNum == 0)
+    {
+      if(is.null(custPolyPath))
+        admLevels <- NULL
+      else
+        admLevels <- NULL
+    } else
+    {
+      admLevels <- NULL
     }
-  }else if (layerNum == 0)
-  {
-    if(is.null(custPolyPath))
-      admLevels <- NULL
-    else
-      admLevels <- NULL
   } else
   {
-    admLevels <- NULL
+    #we are still creating the ctryStruct for a cust poly so use layernames
+    if(length(lowestAdmLevel) == 0 || nchar(lowestAdmLevel)==0)
+    {
+      admLevels <- as.character(allLayers)
+    } else
+    {
+      admLevels <- NULL
+    }
   }
-  
+
   return (admLevels)
 }
 
@@ -903,30 +957,37 @@ getCtryStructAdmLevelNames <- function(ctryCode, lowestAdmLevel, gadmVersion=pkg
 #' }
 #'
 #' @export
-searchAdmLevel <- function(ctryCodes, admLevelNames, dnldPoly=TRUE, downloadMethod=pkgOptions("downloadMethod"), gadmVersion=pkgOptions("gadmVersion"), custPolyPath=NULL)
+searchAdmLevel <- function(ctryCodes=NULL, admLevelNames, dnldPoly=TRUE, downloadMethod=pkgOptions("downloadMethod"), gadmVersion=pkgOptions("gadmVersion"), custPolyPath=NULL)
 {
-  if(missing(ctryCodes))
-    stop("Missing required parameter ctryCode")
+  if(is.null(custPolyPath) && is.null(ctryCodes))
+    stop(Sys.time(), ": Missing required parameter ctryCode")
   
-  if(!allValidCtryCodes(ctryCodes))
-    stop("Invalid ISO3 ctryCode: ", ctryCodes)
+  if(!is.null(ctryCodes) && !allValidCtryCodes(ctryCodes = ctryCodes))
+    stop(Sys.time(), ": Invalid ctryCode(s) detected ")
   
   if(missing(admLevelNames))
     admLevelNames <- NULL
-  #  stop("Missing required parameter admLevelName")
+  #  stop(Sys.time(), ": Missing required parameter admLevelName")
 
   #if(length(admLevelName) > 1)
-  #  stop("Only 1 admLevel allowed")
+  #  stop(Sys.time(), ": Only 1 admLevel allowed")
   
   if(missing(dnldPoly))
     dnldPoly <- TRUE
   
-  admLevels <- sapply(1:length(unlist(ctryCodes)), function(cCodeIdx)
+  #loop over custPolyPaths if present otherwise over ctryCodes
+  #since custPolyPaths can have ctryCodes but not vice versa
+  numLoops <- ifelse(length(custPolyPath) > 0, length(custPolyPath), length(unlist(ctryCodes)))
+  
+  if(numLoops < 1)
+    return(NULL)
+  
+  admLevels <- sapply(1:numLoops, function(cCodeIdx)
   {
     if(!existsCtryPoly(ctryCode = ctryCodes[[cCodeIdx]], gadmVersion = gadmVersion, custPolyPath = custPolyPath))
     {
       if(!dnldPoly)
-        message("ctryPoly doesn't exist. Set dnldPoly=TRUE to download it")
+        message(Sys.time(), ": ctryPoly doesn't exist. Set dnldPoly=TRUE to download it")
       else
         dnldCtryPoly(ctryCode = ctryCodes[[cCodeIdx]], gadmVersion = gadmVersion, custPolyPath = custPolyPath, downloadMethod = downloadMethod)
     }
@@ -949,14 +1010,14 @@ searchAdmLevel <- function(ctryCodes, admLevelNames, dnldPoly=TRUE, downloadMeth
       else if(admLevelName == "all")
         getCtryShpAllAdmLvls(ctryCodes = ctryCodes[[cCodeIdx]], gadmVersion = gadmVersion, custPolyPath = custPolyPath)
       
-      if(!is.null(ctryShpLyrNames))
+      if(length(ctryShpLyrNames) > 0)
         return(unlist(ctryShpLyrNames))
       
       #if 0 or adm0 take the last digit as the layer num
       if(length(grep("\\d+$", admLevelName, ignore.case = T)) > 0)
         idxFound <- as.numeric(stringr::str_extract(admLevelName, "\\d+$"))
       else
-        idxFound <- grep(pattern = admLevelName, x = allAdmLevels, ignore.case = TRUE)
+        idxFound <- grep(pattern = admLevelName, x = allAdmLevels, ignore.case = TRUE)-1
       
       if(length(idxFound) == 0)
       {
@@ -969,7 +1030,9 @@ searchAdmLevel <- function(ctryCodes, admLevelNames, dnldPoly=TRUE, downloadMeth
     })
   })
 
-  stats::setNames(admLevels, ctryCodes)
+  lvlNames <- if(!is.null(custPolyPath)) basename(custPolyPath) else ctryCodes
+  
+  stats::setNames(admLevels, lvlNames)
 }
 
 ######################## validCtryAdmLvls ###################################
@@ -994,23 +1057,23 @@ searchAdmLevel <- function(ctryCodes, admLevelNames, dnldPoly=TRUE, downloadMeth
 #' #returns "KEN_adm1"
 #' }
 #'
-validCtryAdmLvls <- function(ctryCode, admLevels, gadmVersion=pkgOptions("gadmVersion"), custPolyPath=NULL)
+validCtryAdmLvls <- function(ctryCode=NULL, admLevels, gadmVersion=pkgOptions("gadmVersion"), custPolyPath=NULL)
 {
-  if(missing(ctryCode))
-    stop("Missing required parameter ctryCode")
+  if(is.null(ctryCode) && is.null(custPolyPath))
+    stop(Sys.time(), ": Missing required parameter ctryCode")
+  
+  if(!is.null(ctryCode) && !allValidCtryCodes(ctryCodes = ctryCode))
+    stop(Sys.time(), ": Invalid ctryCode(s) detected ")
   
   if(length(ctryCode) > 1)
-    stop("Only one ctryCode can be processed at a time")
-  
-  if(!validCtryCodes(ctryCodes = ctryCode))
-    stop("Invalid ISO3 ctryCode: ", ctryCode)
+    stop(Sys.time(), ": Only one ctryCode can be processed at a time")
   
   ctryAdmLvls <- unlist(getCtryShpAllAdmLvls(ctryCodes = ctryCode, gadmVersion = gadmVersion, custPolyPath = custPolyPath))
   
   validAdmLvls <- sapply(admLevels, function(x) toupper(x) %in% toupper(ctryAdmLvls))
   
   if(!all(validAdmLvls))
-    message("Invalid admLevels: ", ctryCode, ":", admLevels[!validAdmLvls], " in polygon '", getPolyFname(ctryCode = ctryCode, gadmVersion = gadmVersion, custPolyPath = custPolyPath), "'")
+    message(Sys.time(), ": Invalid admLevels: ", ctryCode, ":", admLevels[!validAdmLvls], " in polygon '", getPolyFname(ctryCode = ctryCode, gadmVersion = gadmVersion, custPolyPath = custPolyPath), "'")
   
   return(validAdmLvls)
 }
@@ -1037,7 +1100,7 @@ validCtryAdmLvls <- function(ctryCode, admLevels, gadmVersion=pkgOptions("gadmVe
 #' #returns "KEN_adm1"
 #' }
 #'
-allValidCtryAdmLvls <- function(ctryCode, admLevels, gadmVersion=pkgOptions("gadmVersion"), custPolyPath=NULL)
+allValidCtryAdmLvls <- function(ctryCode=NULL, admLevels, gadmVersion=pkgOptions("gadmVersion"), custPolyPath=NULL)
 {
   return(all(unlist(sapply(1:length(ctryCode), function(cCodeIdx)validCtryAdmLvls(ctryCode = ctryCode[[cCodeIdx]], admLevels = unlist(admLevels[[cCodeIdx]]), gadmVersion = gadmVersion, custPolyPath = custPolyPath)))))
 }
@@ -1060,13 +1123,13 @@ allValidCtryAdmLvls <- function(ctryCode, admLevels, gadmVersion=pkgOptions("gad
 #' #returns TRUE/FALSE
 #' }
 #'
-existsCtryPoly <- function(ctryCode, gadmVersion=pkgOptions("gadmVersion"), custPolyPath=NULL)
+existsCtryPoly <- function(ctryCode=NULL, gadmVersion=pkgOptions("gadmVersion"), custPolyPath=NULL)
 {
-  if(missing(ctryCode))
-    stop("Missing required parameter ctryCode")
+  if(is.null(ctryCode) && is.null(custPolyPath))
+    stop(Sys.time(), ": Missing required parameter ctryCode")
   
-  if(!validCtryCodes(ctryCode))
-    stop("Invalid ISO3 ctryCode: ", ctryCode)
+  if(!is.null(ctryCode) && !allValidCtryCodes(ctryCodes = ctryCode))
+    stop(Sys.time(), ": Invalid ctryCode(s) detected ")
   
   return(dir.exists(getPolyFnamePath(ctryCode = ctryCode, gadmVersion = gadmVersion, custPolyPath = custPolyPath)))
 }
@@ -1091,8 +1154,14 @@ existsCtryPoly <- function(ctryCode, gadmVersion=pkgOptions("gadmVersion"), cust
 #' #returns "KEN_adm1"
 #' }
 #'
-getCtryShpAllAdmLvls <- function(ctryCodes, gadmVersion=pkgOptions("gadmVersion"), custPolyPath=NULL)
+getCtryShpAllAdmLvls <- function(ctryCodes=NULL, gadmVersion=pkgOptions("gadmVersion"), custPolyPath=NULL)
 {
+  if(is.null(custPolyPath) && is.null(ctryCodes))
+    stop(Sys.time(), ": Missing required parameter ctryCode")
+  
+  if(!is.null(ctryCodes) && !allValidCtryCodes(ctryCodes = ctryCodes))
+    stop(Sys.time(), ": Invalid ctryCode(s) detected ")
+  
   stats::setNames(lapply(X = ctryCodes, 
          FUN = function(ctryCode)
          {
@@ -1129,21 +1198,24 @@ getCtryShpAllAdmLvls <- function(ctryCodes, gadmVersion=pkgOptions("gadmVersion"
 #' Rnightlights:::getPolyFname("KEN")
 #'  #returns "KEN_adm_shp"
 #'
-getPolyFname <- function(ctryCode, gadmVersion=pkgOptions("gadmVersion"), custPolyPath=NULL)
+getPolyFname <- function(ctryCode=NULL, gadmVersion=pkgOptions("gadmVersion"), custPolyPath=NULL)
 {
-  if(missing(ctryCode))
-    stop("Missing required parameter ctryCode")
+  if(is.null(ctryCode) && is.null(custPolyPath))
+    stop(Sys.time(), ": Missing required parameter. One of ctryCode/custPolyPath required")
   
-  if(!validCtryCodes(ctryCode))
-    stop("Invalid ctryCode: ", ctryCode)
+  if(!is.null(ctryCode) && !validCtryCodes(ctryCode))
+    stop(Sys.time(), ": Invalid ctryCode: ", ctryCode)
 
   #if any value is given for custAdmPoly override GADM
   if(!is.null(custPolyPath))
   {
+    if(missing(ctryCode))
+      ctryCode <- NULL
+    
     fName <- basename(custPolyPath)
     
     #format of shapefiles is CTR_adm_shp e.g. KEN_adm_shp
-    polyFname <- paste0("SHP_", ctryCode, "_CUST-", fName)
+    polyFname <- paste0("SHP_", ifelse(is.null(ctryCode), "", paste0(ctryCode,"_")), "CUST-", fName)
   }else
   {
     #format of shapefiles is CTR_adm_shp e.g. KEN_adm_shp
@@ -1177,13 +1249,13 @@ getPolyFname <- function(ctryCode, gadmVersion=pkgOptions("gadmVersion"), custPo
 #'  
 #' #@export only due to exploreData() shiny app
 #' @export
-getPolyFnamePath <- function(ctryCode, gadmVersion=pkgOptions("gadmVersion"), custPolyPath=NULL)
+getPolyFnamePath <- function(ctryCode=NULL, gadmVersion=pkgOptions("gadmVersion"), custPolyPath=NULL)
 {
-  if(missing(ctryCode))
-    stop("Missing required parameter ctryCode")
+  if(is.null(ctryCode) && is.null(custPolyPath))
+    stop(Sys.time(), ": Missing required parameter. One of ctryCode/custPolyPath required")
   
-  if(!validCtryCodes(ctryCode))
-    stop("Invalid ctryCode: ", ctryCode)
+  if(!is.null(ctryCode) && !validCtryCodes(ctryCode))
+    stop(Sys.time(), ": Invalid ctryCode: ", ctryCode)
   
   #check for the shapefile directory created with
   #format of shapefiles is CTR_adm_shp e.g. KEN_adm_shp
@@ -1210,13 +1282,13 @@ getPolyFnamePath <- function(ctryCode, gadmVersion=pkgOptions("gadmVersion"), cu
 #' Rnightlights:::getPolyFnameZip("KEN")
 #'  #returns "path/to/"
 #'
-getPolyFnameZip <- function(ctryCode, gadmVersion=pkgOptions("gadmVersion"), custPolyPath=NULL)
+getPolyFnameZip <- function(ctryCode=NULL, gadmVersion=pkgOptions("gadmVersion"), custPolyPath=NULL)
 {
-  if(missing(ctryCode))
-    stop("Missing required parameter ctryCode")
+  if(is.null(ctryCode) && is.null(custPolyPath))
+    stop(Sys.time(), ": Missing required parameter ctryCode")
   
-  if(!validCtryCodes(ctryCodes = ctryCode))
-    stop("Invalid ctryCode: ", ctryCode)
+  if(!is.null(ctryCode) && !allValidCtryCodes(ctryCodes = ctryCode))
+    stop(Sys.time(), ": Invalid ctryCode(s) detected ")
   
   #format of shapefiles is <ctryCode>_adm_shp e.g. KEN_adm_shp
   polyFname <- paste0(getPolyFnamePath(ctryCode = ctryCode, gadmVersion = gadmVersion, custPolyPath = custPolyPath),".zip")
@@ -1242,13 +1314,13 @@ getPolyFnameZip <- function(ctryCode, gadmVersion=pkgOptions("gadmVersion"), cus
 #' Rnightlights:::getPolyFnameZip("KEN")
 #'  #returns "path/to/"
 #'
-getPolyFnameRDS <- function(ctryCode, gadmVersion=pkgOptions("gadmVersion"), custPolyPath=NULL)
+getPolyFnameRDS <- function(ctryCode=NULL, gadmVersion=pkgOptions("gadmVersion"), custPolyPath=NULL)
 {
-  if(missing(ctryCode))
-    stop("Missing required parameter ctryCode")
+  if(is.null(ctryCode) && is.null(custPolyPath))
+    stop(Sys.time(), ": Missing required parameter ctryCode")
   
-  if(!validCtryCodes(ctryCodes = ctryCode))
-    stop("Invalid ctryCode: ", ctryCode)
+  if(!is.null(ctryCode) && !allValidCtryCodes(ctryCodes = ctryCode))
+    stop(Sys.time(), ": Invalid ctryCode(s) detected ")
   
   #format of shapefiles is <ctryCode>_adm_shp e.g. KEN_adm_shp
   polyFname <- paste0(getPolyFnamePath(ctryCode = ctryCode, gadmVersion = gadmVersion, custPolyPath = custPolyPath), ".RDS")
@@ -1280,23 +1352,27 @@ getPolyFnameRDS <- function(ctryCode, gadmVersion=pkgOptions("gadmVersion"), cus
 #'   Rnightlights:::ctryShpLyrName2Num("KEN", "KEN_adm1") #returns 1
 #' }
 #'
-ctryShpLyrName2Num <- function(ctryCode, layerName, gadmVersion = pkgOptions("gadmVersion"), custPolyPath=NULL)
+ctryShpLyrName2Num <- function(ctryCode=NULL, layerName, gadmVersion = pkgOptions("gadmVersion"), custPolyPath=NULL)
 {
+  if(is.null(ctryCode) && is.null(custPolyPath))
+    stop(Sys.time(), ": Missing required parameter ctryCode")
+  
+  if(!is.null(ctryCode) && !allValidCtryCodes(ctryCodes = ctryCode))
+    stop(Sys.time(), ": Invalid ctryCode(s) detected ")
+  
   if(missing(layerName))
-    stop("Missing required parameter layerName")
+    stop(Sys.time(), ": Missing required parameter layerName")
   
   if (class(layerName) != "character" || is.null(layerName) || is.na(layerName) || layerName =="")
-    stop("Invalid layerName: ", layerName)
+    stop(Sys.time(), ": Invalid layerName: ", layerName)
   
   allLyrNames <- rgdal::ogrListLayers(dsn = getPolyFnamePath(ctryCode = ctryCode, gadmVersion = gadmVersion, custPolyPath = custPolyPath))
   
   #if gadm layers are listed out of order sort them
-  #for custpolypath remove the index prefix e.g. 1_
+  #custPolyPaths will have been named in order
   if(is.null(custPolyPath))
     allLyrNames <- sort(allLyrNames)
-  #else
-  #  allLyrNames <- gsub("^\\d+_", "", allLyrNames)
-  
+
   return(which(allLyrNames == layerName)-1)
 }
 
@@ -1332,21 +1408,21 @@ ctryShpLyrName2Num <- function(ctryCode, layerName, gadmVersion = pkgOptions("ga
 #' }
 #'
 #' @export
-readCtryPolyAdmLayer <- function(ctryCode, admLevel, polyType="rds", dnldPoly=TRUE, gadmVersion=pkgOptions("gadmVersion"), custPolyPath=NULL)
+readCtryPolyAdmLayer <- function(ctryCode=NULL, admLevel, polyType="rds", dnldPoly=TRUE, gadmVersion=pkgOptions("gadmVersion"), custPolyPath=NULL)
 {
-  if(missing(ctryCode))
-    stop("Missing required parameter ctryCode")
+  if(is.null(ctryCode) && is.null(custPolyPath))
+    stop(Sys.time(), ": Missing required parameter ctryCode")
   
-  if(!validCtryCodes(ctryCode))
-    stop("Invalid ISO3 ctryCode: ", ctryCode)
+  if(!is.null(ctryCode) && !allValidCtryCodes(ctryCodes = ctryCode))
+    stop(Sys.time(), ": Invalid ctryCode(s) detected ")
   
   if(missing(admLevel))
-    stop("Missing required parameter admLevelName")
+    stop(Sys.time(), ": Missing required parameter admLevelName")
   
   if(!existsCtryPoly(ctryCode = ctryCode, gadmVersion = gadmVersion, custPolyPath = custPolyPath))
   {
     if(!dnldPoly)
-      message("ctryPoly doesn't exist. Set dnldPoly=TRUE to download it")
+      message(Sys.time(), ": ctryPoly doesn't exist. Set dnldPoly=TRUE to download it")
     else
       dnldCtryPoly(ctryCode = ctryCode, gadmVersion = gadmVersion, custPolyPath = custPolyPath)
   }
@@ -1360,7 +1436,7 @@ readCtryPolyAdmLayer <- function(ctryCode, admLevel, polyType="rds", dnldPoly=TR
       if(dnldPoly)
         dnldCtryPoly(ctryCode = ctryCode, gadmVersion = gadmVersion, custPolyPath = custPolyPath)
       else
-        stop("RDS doesn't exist. Set dnldPoly=TRUE to download/create it")
+        stop(Sys.time(), ": RDS doesn't exist. Set dnldPoly=TRUE to download/create it")
     }
     
     if(file.exists(rdsPath))
@@ -1373,7 +1449,7 @@ readCtryPolyAdmLayer <- function(ctryCode, admLevel, polyType="rds", dnldPoly=TR
     }
     else
     {
-      stop("Unable to retrieve RDS. Retry with dnldPoly=TRUE to download/create it")
+      stop(Sys.time(), ": Unable to retrieve RDS. Retry with dnldPoly=TRUE to download/create it")
     }
     
   }
@@ -1386,7 +1462,7 @@ readCtryPolyAdmLayer <- function(ctryCode, admLevel, polyType="rds", dnldPoly=TR
       if(dnldPoly)
         dnldCtryPoly(ctryCode = ctryCode, gadmVersion = gadmVersion, custPolyPath = custPolyPath)
       else
-        stop("Shapefile doesn't exist. Set dnldPoly=TRUE to download it")
+        stop(Sys.time(), ": Shapefile doesn't exist. Set dnldPoly=TRUE to download it")
     }
     
     if(dir.exists(shpPath))
@@ -1395,7 +1471,7 @@ readCtryPolyAdmLayer <- function(ctryCode, admLevel, polyType="rds", dnldPoly=TR
     }
     else
     {
-      stop("Shapefile not found. set dnldPoly=TRUE to download shapefile and save as RDS")
+      stop(Sys.time(), ": Shapefile not found. set dnldPoly=TRUE to download shapefile and save as RDS")
     }
   }
   
