@@ -21,18 +21,25 @@
 validNlStats <- function(nlStats)
 {
   if(missing(nlStats))
-    stop("Missing required parameter nlStats")
+    stop(Sys.time(), ": Missing required parameter nlStats")
   
-  if(!is.character(nlStats) || is.null(nlStats) || is.na(nlStats) || nlStats == "")
-    stop("Invalid nlStats")
+  if((!is.character(nlStats) && !is.list(nlStats)) || is.null(nlStats) || is.na(nlStats) || nlStats == "")
+    stop(Sys.time(), ": Invalid nlStats")
+  
+  if(is.list(nlStats) && length(nlStats) > 1 && all(sapply(2:length(nlStats), function(i) !is.list(nlStats[[i]]) && (grepl("=", nlStats[i]) || length(names(nlStats[i])) > 0))))
+    nlStats <- list(nlStats)
   
   matchedFuns <- sapply(nlStats, function(nlStat)
     tryCatch(
     {
-      matched <- !is.null(match.fun(nlStat))
+      if(is.list(nlStat) && all(sapply(2:length(nlStat), function(i) grepl("=", nlStat[i]) || length(names(nlStat[i])) > 0)))
+        matched <- is.character(nlStat[[1]]) && !is.null(match.fun(nlStat[[1]]))
+      else
+        matched <- is.character(nlStat) && !is.null(match.fun(nlStat))
     }, error = function(err)
     {
-      message(paste0("Invalid nlStat: ", nlStat))
+      #sep when a=b without a name may cause fn(=param=arg...)
+      message(Sys.time(), ": ", paste0("Invalid nlStat: ", gsub("\\(=|,=|funArgs=","\\(", paste0(as.character(nlStat[[1]]), "(", paste(names(nlStat[-1]), nlStat[-1], sep = "=", collapse=",") ,")"))))
       matched <- FALSE
       return(matched)
     }
@@ -48,13 +55,18 @@ validNlStats <- function(nlStats)
 #' Calculate zonal statistics. Used internally by zonalpipe. Modified from 
 #'     \url{http://www.guru-gis.net/efficient-zonal-statistics-using-r-and-gdal/}
 #'
-#' @param x the country raster
+#' @param rast the country raster
 #'
-#' @param z the zonal country polygon layer
+#' @param zone the zonal country polygon layer
 #'
 #' @param nlStats a character list of statistics to calculate
 #'
 #' @param digits round off to how many decimals
+#' 
+#' @param retVal Whether to return the raster data as a vector, or 
+#'     data.frame with spatial context NULL returns a vector of all
+#'     values, colrowval returns a data.frame with row, col and raster
+#'     value while lonlatval returns a data.frame with lon,lat and val.
 #'
 #' @param na.rm how to handle NAs
 #'
@@ -63,31 +75,67 @@ validNlStats <- function(nlStats)
 #' @return numeric value result of the given nlStat function
 #' 
 #' @import data.table
-myZonal <- function (x, z, nlStats, digits = 0, na.rm = TRUE, ...)
+myZonal <- function (rast, zone, nlStats, digits = 0, retVal=NULL, na.rm = TRUE, ...)
 {
   options(fftempdir=getNlDir("dirNlTemp"), fffinalizer="delete")
   
-  #vreate the text for the functions
-  fun <- paste0(sapply(nlStats, function(nlStat) paste0(nlStat,"=", nlStat, "(x, na.rm = TRUE)")), collapse = ", ")
-
-  #create the aggregation function
-  funs <- paste0("dta[, as.list(unlist(lapply(.SD, function(x) list(", fun, ")))), by=zones]")
+  options(stringsAsFactors = FALSE)
+  
+  #retVal <- "colrowval"
   
   vals <- NULL
   
   zones <- NULL
   
-  message("Reading in raster data")
+  #create the text for the functions
+  fun <- sapply(nlStats,
+                       function(nlStat)
+                       {
+                         #remove preceding = from "(=" or ",="
+                         if(length(nlStat) > 1)
+                           nlStatParams <- gsub("(\\(\\s*)=|(,\\s*)=", "\\1\\2", paste0(", ", paste(names(nlStat[-1]),nlStat[-1], sep="=", collapse=",")))
+                         else
+                           nlStatParams <- NULL
+                         
+                         nlStat <- nlStat[[1]]
+                         
+                         #paste0(nlStat,"=", nlStat, "(x, na.rm = TRUE)")
+                         nlStatArgs <- formals(nlStat)
+                         
+                         retVal <- if(all(sapply(c("col","row"), "%in%",names(nlStatArgs))))
+                           "colrowval"
+                         else if(all(sapply(c("lon","lat"), "%in%",names(nlStatArgs))))
+                           "lonlatval"
+                         else
+                           NULL
+                         
+                         fnTxt <- if(is.null(retVal))
+                           paste0(nlStat, "(vals", nlStatParams, ")")
+                         else if(retVal == "colrowval")
+                           paste0(nlStat, "(col=cols, row=rows, val=vals", nlStatParams, ")")
+                         else if(retVal == "lonlatval")
+                           paste0(nlStat, "(lon=lons, lat=lats, val=vals", nlStatParams, ")") 
+                        })
+
+  funNames <- gsub("\\(.*\\)", "", fun)
+  
+  #create the aggregation function
+  #funs <- paste0("dta[, as.list(unlist(lapply(.SD, function(dta) list(", paste(fun, collapse=","), ")))), by=zones]")
+  funs <- paste0("dta[, as.list(unlist(stats::setNames(lapply(fun, function(fn) eval(parse(text=fn))), funNames))), by=zones]")
+  
+  message(Sys.time(), ": Reading in raster data")
 
   #the number of columns in the raster/zone file which are identical in size
-  nc <- base::ncol(x)
+  nc <- base::ncol(rast)
   
   #get the block size recommendation
-  tr <- raster::blockSize(x)
+  tr <- raster::blockSize(rast)
   
   #init the progress bar
   pb <- utils::txtProgressBar(min=0, max=tr$n, style=3)
   
+  rowVals <- colVals <- lonVals <- latVals <- NULL
+  
   #for each block
   for (i in 1:tr$n)
   {
@@ -95,9 +143,15 @@ myZonal <- function (x, z, nlStats, digits = 0, na.rm = TRUE, ...)
     
     end <- start + (tr$nrows[i] * nc) - 1
     
-    rastVals <- raster::getValues(x, row=tr$row[i], nrows=tr$nrows[i])
-    zoneVals <- raster::getValues(z, row=tr$row[i], nrows=tr$nrows[i])
-   
+    rastVals <- raster::getValuesBlock(rast, row=tr$row[i], nrows=tr$nrows[i])
+    zoneVals <- raster::getValuesBlock(zone, row=tr$row[i], nrows=tr$nrows[i])
+
+    colrowVals <- stats::setNames(expand.grid(tr$row[i]:(tr$row[i]+tr$nrows[i]-1), 1:rast@ncols), c("cols","rows"))
+
+    extent <- raster::extent(rast)
+    lonlatVals <- stats::setNames(expand.grid(seq(extent@xmin,extent@xmax,(extent@xmax-extent@xmin)/(rast@ncols-1)),
+                          seq(extent@ymin,extent@ymax,(extent@ymax-extent@ymin)/(tr$nrows[i]-1))), c("lons","lats"))
+    
     #convert negative values to NA 
     rastVals[rastVals < 0] <- NA
     
@@ -110,17 +164,30 @@ myZonal <- function (x, z, nlStats, digits = 0, na.rm = TRUE, ...)
     zoneVals <- zoneVals[-idxZone0]
     rastVals <- rastVals[-idxZone0]
     
+    colrowVals <- colrowVals[-idxZone0,]
+    lonlatVals <- lonlatVals[-idxZone0,]
+
     #for first block init the ff to the given filename
     if (i == 1)
     {
       vals <- ff::ff(initdata = rastVals, finalizer = "delete", overwrite = T)
       zones <- ff::ff(initdata = zoneVals, finalizer = "delete", overwrite = T)
+      
+      cols <- ff::ff(initdata = colrowVals$cols, finalizer = "delete", overwrite = T)
+      rows <- ff::ff(initdata = colrowVals$rows, finalizer = "delete", overwrite = T)
+      lons <- ff::ff(initdata = lonlatVals$lons, finalizer = "delete", overwrite = T)
+      lats <- ff::ff(initdata = lonlatVals$lats, finalizer = "delete", overwrite = T)
     } 
     else 
     {
       #otherwise append
       vals <- ffbase::ffappend(vals, rastVals, adjustvmode = T)
       zones <- ffbase::ffappend(zones, zoneVals, adjustvmode = T)
+
+      cols <- ffbase::ffappend(cols, colrowVals$cols, adjustvmode = T)
+      rows <- ffbase::ffappend(rows, colrowVals$rows, adjustvmode = T)
+      lons <- ffbase::ffappend(lons, lonlatVals$lons, adjustvmode = T)
+      lats <- ffbase::ffappend(lats, lonlatVals$lats, adjustvmode = T)
     }
     
     #upddate progress bar
@@ -130,12 +197,13 @@ myZonal <- function (x, z, nlStats, digits = 0, na.rm = TRUE, ...)
   close(pb)
   
   #merge the zone and raster ffvectors into an ffdf
-  rDT <- ff::ffdf(zones, vals)
+  rDT <- ff::ffdf(zones, cols, rows, vals, lons, lats)
 
-  message("Calculating nlStats ", base::date())
+  message(Sys.time(), ": Calculating nlStats ")
   
-  if(length(unique(rDT$zones) == 1))
+  if(length(unique(rDT$zones)) == 1)
   {
+    #no longer required. fixed bug in ffdfdply when zone was length 1
     dta <- data.table::as.data.table(rDT)
     
     result <- eval(parse(text = funs))
@@ -150,7 +218,7 @@ myZonal <- function (x, z, nlStats, digits = 0, na.rm = TRUE, ...)
   result <- ffbase::ffdfdply(x=rDT,
                              split=as.character(zones),
                              trace=TRUE,
-                             BATCHBYTES = 80.85*2^20,
+                             BATCHBYTES = 80.85*2^20, #try approx 1% of RAM
                              FUN = function(dta){
                                ## This happens in RAM - containing **several** split 
                                #elements so here we can use data.table which works 
@@ -161,12 +229,38 @@ myZonal <- function (x, z, nlStats, digits = 0, na.rm = TRUE, ...)
                                result <- eval(parse(text = funs))
                                
                                as.data.frame(result)
+                               
                              })
   }
-  #name the columns
-  result <- stats::setNames(result, c("z", nlStats))
-
-  resultDF <- as.data.frame(result)
+  
+  result <- as.data.table(result)
+  
+  #count cols with nlStat in them
+  nlStatColCounts <- sapply(funNames, function(funName) length(grep(paste0("^", funName,"\\.*"), names(result))))
+  
+  #collapse multi-value cols into one
+  for(funName in funNames)
+  {
+    if(nlStatColCounts[[funName]] > 1)
+    {
+      message(Sys.time(), ": ", funName, " => Multi-column result detected. Merging")
+      #if more than one col detected, get their names
+      nlStatCols <- grep(funName, names(result), value = T)
+      
+      #merge them row-wise into one character vector separated by comma
+      result[[funName]] <- apply(result[, nlStatCols, with=F], 1, function(x) paste(x, collapse=","))
+      
+      #remove the separate cols
+      result[,c(nlStatCols) := NULL]
+    }else
+    {
+      nlStatCols <- grep(funName, names(result), value = T)
+      
+      names(result)[which(names(result)==nlStatCols)] <- funName
+    }
+  }
+  
+  resultDF <- as.data.frame(result[,c("zones",funNames), with=F])
   
   ff::delete(rDT, result)
   rm(rDT, result)
@@ -219,38 +313,38 @@ ZonalPipe <- function (ctryCode, admLevel, ctryPoly, path.in.shp, path.in.r, pat
   #nlStat: function to summary path.in.r values ("mean", "sum"...)
   
   if(missing(ctryCode))
-    stop("Missing required parameter ctryCode")
+    stop(Sys.time(), ": Missing required parameter ctryCode")
   
   if(missing(ctryCode))
-    stop("Missing required parameter ctryCode")
+    stop(Sys.time(), ": Missing required parameter ctryCode")
   
   if(missing(path.in.shp))
-    stop("Missing required parameter path.in.shp")
+    stop(Sys.time(), ": Missing required parameter path.in.shp")
   
   if(missing(path.in.r))
-    stop("Missing required parameter path.in.r")
+    stop(Sys.time(), ": Missing required parameter path.in.r")
   
   if(missing(path.out.r))
-    stop("Missing required parameter path.out.r")
+    stop(Sys.time(), ": Missing required parameter path.out.r")
   
   if(missing(zone.attribute))
-    stop("Missing required parameter zone.attribute")
+    stop(Sys.time(), ": Missing required parameter zone.attribute")
   
   if(missing(nlStats))
-    stop("Missing required parameter nlStats")
+    stop(Sys.time(), ": Missing required parameter nlStats")
   
   if(!validCtryCodes(ctryCode))
-    stop("Invalid ctryCode: ", ctryCode)
+    stop(Sys.time(), ": Invalid ctryCode: ", ctryCode)
   
   if(!allValid(nlStats, validNlStats))
-    stop("Invalid stat(s) detected")
+    stop(Sys.time(), ": Invalid stat(s) detected")
   
   # 1/ Rasterize using GDAL
   
   # Find a better multi-platform way to check for gdal.
   # suppressWarnings(
   #   if(system("which gdal_rasterize", intern = T) != 0)
-  #     stop("gdal_rasterize not found. Please check that GDAL is installed")
+  #     stop(Sys.time(), ": gdal_rasterize not found. Please check that GDAL is installed")
   # )
   
   #Initiate parameter
@@ -258,7 +352,7 @@ ZonalPipe <- function (ctryCode, admLevel, ctryPoly, path.in.shp, path.in.r, pat
   
   if (!file.exists(path.out.r))
   {
-    message("Zonal file ", path.out.r, " doesn't exist. Creating", date())
+    message(Sys.time(), ": Zonal file ", path.out.r, " doesn't exist. Creating", date())
     
     #get the extent and change to minx, miny, maxx, maxy order for use
     #in gdal_rasterize. Explanation below
@@ -285,7 +379,7 @@ ZonalPipe <- function (ctryCode, admLevel, ctryPoly, path.in.shp, path.in.r, pat
     tempRast <- file.path(getNlDir("dirNlTemp"), paste0(basename(tempfile()), ".tif"))
     
     #Gdal_rasterize
-    message("Creating zonal raster")
+    message(Sys.time(), ": Creating zonal raster")
     command<-'gdal_rasterize'
     #Speed-up with more cache (avice: max 1/3 of your total RAM)
     command<-paste(command, paste0("--config GDAL_CACHEMAX ", pkgOptions("gdalCacheMax")))
@@ -305,7 +399,7 @@ ZonalPipe <- function (ctryCode, admLevel, ctryPoly, path.in.shp, path.in.r, pat
     
     system(command)
     
-    message("Compressing zonal raster")
+    message(Sys.time(), ": Compressing zonal raster")
     gdalUtils::gdal_translate(co = "compress=LZW", 
                               src_dataset = tempRast, 
                               dst_dataset = path.out.r)
@@ -314,19 +408,19 @@ ZonalPipe <- function (ctryCode, admLevel, ctryPoly, path.in.shp, path.in.r, pat
   }
   
   if(file.exists(path.out.r))
-    message("Zonal file ", path.out.r, " found")
+    message(Sys.time(), ": Zonal file ", path.out.r, " found")
   else
     stop(path.out.r, " not found. Zonal creation failed.")
   
   # 2/ Zonal Stat using myZonal function
   zone<-raster::raster(path.out.r)
   
-  message("Calculating zonal stats ...", date())
+  message(Sys.time(), ": Calculating zonal stats ...")
   Zstat<-data.frame(myZonal(r, zone, nlStats))
   
-  message("Calculating zonal stats ... DONE", date())
+  message(Sys.time(), ": Calculating zonal stats ... DONE")
 
-  colnames(Zstat)[2:length(Zstat)] <- nlStats
+  colnames(Zstat)[2:length(Zstat)] <- sapply(nlStats, function(x) x[[1]])
   
   return(Zstat)
   
@@ -379,19 +473,19 @@ ZonalPipe <- function (ctryCode, admLevel, ctryPoly, path.in.shp, path.in.r, pat
 fnAggRadGdal <- function(ctryCode, admLevel, ctryPoly, nlType, nlPeriod, nlStats=pkgOptions("nlStats"), gadmVersion=pkgOptions("gadmVersion"), custPolyPath=NULL)
 {
   if(missing(ctryCode))
-    stop("Missing required parameter ctryCode")
+    stop(Sys.time(), ": Missing required parameter ctryCode")
   
   if(missing(nlPeriod))
-    stop("Missing required parameter nlPeriod")
+    stop(Sys.time(), ": Missing required parameter nlPeriod")
   
   if(!validCtryCodes(ctryCode))
-    stop("Invalid ctryCode: ", ctryCode)
+    stop(Sys.time(), ": Invalid ctryCode: ", ctryCode)
   
   if(!allValidNlPeriods(nlPeriods = nlPeriod, nlTypes = nlType))
-    stop("Invalid nlPeriod: ", nlPeriod, " for nlType: ", nlType)
+    stop(Sys.time(), ": Invalid nlPeriod: ", nlPeriod, " for nlType: ", nlType)
   
   if(!allValid(nlStats, validNlStats))
-    stop("Invalid stat(s) detected")
+    stop(Sys.time(), ": Invalid stat(s) detected")
   
   #source: http://www.guru-gis.net/efficient-zonal-statistics-using-r-and-gdal/
   
@@ -438,7 +532,17 @@ fnAggRadGdal <- function(ctryCode, admLevel, ctryPoly, nlType, nlPeriod, nlStats
     paste0("GID_IDX")
   }
   
-  sumAvgRad <- ZonalPipe(ctryCode = ctryCode, admLevel = admLevel, ctryPoly = ctryPoly, path.in.shp = path.in.shp, path.in.r = path.in.r, path.out.r = path.out.r, path.out.shp = path.out.shp, zone.attribute = zone.attribute, nlStats=nlStats, gadmVersion = gadmVersion, custPolyPath = custPolyPath)
+  sumAvgRad <- ZonalPipe(ctryCode = ctryCode,
+                         admLevel = admLevel,
+                         ctryPoly = ctryPoly,
+                         path.in.shp = path.in.shp,
+                         path.in.r = path.in.r,
+                         path.out.r = path.out.r,
+                         path.out.shp = path.out.shp,
+                         zone.attribute = zone.attribute,
+                         nlStats = nlStats,
+                         gadmVersion = gadmVersion,
+                         custPolyPath = custPolyPath)
   
   ctryPolyData <- ctryPoly@data
   
@@ -449,13 +553,13 @@ fnAggRadGdal <- function(ctryCode, admLevel, ctryPoly, nlType, nlPeriod, nlStats
   #if there is only the country adm level i.e. no lower adm levels than the country adm level then we only have 1 row each but IDs may not match as seen with ATA. treat differently
   #since we do not have IDs to merge by, we simply cbind the columns and return column 2
 
-  if (grepl("ID_0",lyrIDCol))
+  if (grepl("^ID_0$",lyrIDCol))
   {
     sumAvgRad <- cbind(ctryPolyData$ID_0, sumAvgRad[sumAvgRad$z!=0, ])
   }
   else
   {
-    sumAvgRad <- merge(ctryPolyData, sumAvgRad, by.x=lyrIDCol, by.y="z", all.x=T, sort=T)
+    sumAvgRad <- merge(ctryPolyData, sumAvgRad, by.x=lyrIDCol, by.y="zones", all.x=T, sort=T)
   }
   
   return(sumAvgRad)
@@ -504,23 +608,25 @@ fnAggRadGdal <- function(ctryCode, admLevel, ctryPoly, nlType, nlPeriod, nlStats
 fnAggRadRast <- function(ctryPoly, ctryRastCropped, nlType, nlStats, custPolyPath=NULL)
 {
   if(missing(ctryPoly))
-    stop("Missing required parameter ctryPoly")
+    stop(Sys.time(), ": Missing required parameter ctryPoly")
   
   if(missing(ctryRastCropped))
-    stop("Missing required parameter ctryRastCropped")
+    stop(Sys.time(), ": Missing required parameter ctryRastCropped")
   
   if ((class(ctryPoly) != "SpatialPolygons" && class(ctryPoly) != "SpatialPolygonsDataFrame" ) || is.null(ctryPoly))
-    stop("Invalid ctryPoly type: ", class(ctryPoly))
+    stop(Sys.time(), ": Invalid ctryPoly type: ", class(ctryPoly))
   
   if (class(ctryRastCropped) != "RasterLayer" || is.null(ctryRastCropped))
-    stop("Invalid ctryRastCropped type: ", class(ctryRastCropped))
+    stop(Sys.time(), ": Invalid ctryRastCropped type: ", class(ctryRastCropped))
   
   if(missing(nlType))
-    stop("Missing required parameter nlType")
+    stop(Sys.time(), ": Missing required parameter nlType")
   
   if(!allValid(nlStats, validNlStats))
-    stop("Invalid stat(s) detected")
+    stop(Sys.time(), ": Invalid stat(s) detected")
 
+  options(stringsAsFactors = FALSE)
+  
   cl <- snow::makeCluster(pkgOptions("numCores"))
   
   doSNOW::registerDoSNOW(cl = cl)
@@ -532,30 +638,90 @@ fnAggRadRast <- function(ctryPoly, ctryRastCropped, nlType, nlStats, custPolyPat
   #to avoid RCheck notes
   i <- NULL
   
-  sumAvgRad <- foreach::foreach(i=1:nrow(ctryPoly@data), 
-                                .combine=rbind,
-                                .export = c("masqOLS", "masqVIIRS", nlStats),
-                                .packages = c("raster"),
-                                .options.snow = list(progress=progress)) %dopar% {
-                                  
+  nlStatNames <- sapply(nlStats, function(x) x[[1]])
+  
+  result <- foreach::foreach(i=1:nrow(ctryPoly@data),
+                              .combine=rbind,
+                              .export = c("masqOLS", "masqVIIRS", nlStatNames),
+                              .packages = c("raster"),
+                              .options.snow = list(progress=progress)) %dopar% {
+  #for(i in 1:nrow(ctryPoly@data)){
+                                
+                                  options(stringsAsFactors = FALSE)
+                                
                                   pid <- Sys.getpid()
                                   
-                                  message("PID:", pid, " Extracting data from polygon " , i, " ", base::date())
+                                  message(Sys.time(), ": PID:", pid, " Extracting data from polygon " , i)
                                   
                                   if(stringr::str_detect(nlType, "OLS"))
-                                    dat <- masqOLS(ctryPoly, ctryRastCropped, i)
+                                    dta <- masqOLS(ctryPoly, ctryRastCropped, i)
                                   else if(stringr::str_detect(nlType, "VIIRS"))
-                                    dat <- masqVIIRS(ctryPoly, ctryRastCropped, i)
+                                    dta <- masqVIIRS(ctryPoly, ctryRastCropped, i)
                                   
-                                  message("PID:", pid, " Calculating the NL stats of polygon ", i, " ", base::date())
+                                  message(Sys.time(), ": PID:", pid, " Calculating the NL stats of polygon ", i)
                                   
-                                  #calculate and return the mean of all the pixels
-                                  #data.frame(sum = sum(dat, na.rm=TRUE))
-                                  
-                                  sumAvgRad <- data.frame(sapply(nlStats, FUN=function(nlStat) data.frame(nlStat = eval(parse(text=paste0(nlStat, "(dat, na.rm=TRUE)"))))))
-                                  
-                                  stats::setNames(sumAvgRad, nlStats)
+                                  result <- data.frame(
+                                        lapply(nlStats,
+                                               FUN=function(nlStat)
+                                               {
+                                                 if(length(nlStat) > 1)
+                                                   nlStatParams <- gsub("(\\(\\s*)=|(,\\s*)=", "\\1\\2", paste0(", ", paste(names(nlStat[-1]),nlStat[-1], sep="=", collapse=",")))
+                                                 else
+                                                   nlStatParams <- NULL
+                                                 
+                                                 nlStat = nlStat[[1]]
+                                                 
+                                                 nlStatArgs <- formals(nlStat)
+                                                 
+                                                 retVal <- if(all(sapply(c("col","row"), "%in%",names(nlStatArgs))))
+                                                   "colrowval"
+                                                 else if(all(sapply(c("lon","lat"), "%in%",names(nlStatArgs))))
+                                                   "lonlatval"
+                                                 else
+                                                   NULL
+
+                                                 fnTxt <- if(is.null(retVal))
+                                                   paste0(nlStat, "(dta$vals", nlStatParams, ")")
+                                                 else if(retVal == "colrowval")
+                                                   paste0(nlStat, "(col=dta$cols, row=dta$rows, val=dta$vals", nlStatParams, ")")
+                                                 else if(retVal == "lonlatval")
+                                                   paste0(nlStat, "(lon=dta$lons, lat=dta$lats, val=dta$vals", nlStatParams, ")")
+                                                 #browser()
+                                                 fnTxt <- paste0("data.frame('", nlStat, "' = matrix(", fnTxt, ", nrow=1))")
+                                                 eval(parse(text=fnTxt))
+                                               }
+                                               )
+                                        )
                                 }
+
+  #count cols with nlStat in them
+  nlStatColCounts <- sapply(nlStatNames, function(nlStat) length(grep(paste0("^",nlStat,"\\.*"), names(result))))
+  
+  #collapse multi-value cols into one
+  for(nlStatName in nlStatNames)
+  {
+    if(nlStatColCounts[[nlStatName]] > 1)
+    {
+      message(Sys.time(), ": ", nlStatName, " => Multi-column result detected. Merging")
+      
+      #if more than one col detected, get their names
+      nlStatCols <- grep(nlStatName, names(result), value = T)
+
+      #merge them row-wise into one character vector separated by comma
+      result[[nlStatName]] <- apply(result[, nlStatCols], 1, function(x) paste(x, collapse=","))
+      
+      #remove the separate cols
+      result[,nlStatCols] <- NULL
+    }else
+    {
+      nlStatCols <- grep(nlStatName, names(result), value = T)
+      
+      names(result)[which(names(result)==nlStatCols)] <- nlStatName
+    }
+  }
+  
+  #change the col order to the order of nlStats
+  result <- result[, nlStatNames]
   
   close(pb)
   snow::stopCluster(cl)
@@ -564,5 +730,5 @@ fnAggRadRast <- function(ctryPoly, ctryRastCropped, nlType, nlStats, custPolyPat
   
   gc()
   
-  return(sumAvgRad)
+  return(stats::setNames(data.frame(result), nlStatNames))
 }
